@@ -1,5 +1,6 @@
 use super::ni_object_net::NiObjectNET;
-use anyhow;
+use crate::common::{Matrix33, Vector3};
+
 use binread::{
     io::{Read, Seek},
     BinRead, BinReaderExt,
@@ -9,8 +10,8 @@ use binread::{
 pub struct NiAvObject {
     pub base: NiObjectNET,
     pub flags: u16,
-    pub translation: (f32, f32, f32),
-    pub rotation: ((f32, f32, f32), (f32, f32, f32), (f32, f32, f32)),
+    pub translation: Vector3,
+    pub rotation: Matrix33,
     pub scale: f32,
     pub num_property_refs: u32,
     #[br(count = num_property_refs)]
