@@ -5,17 +5,21 @@ mod ni_psys_box_emitter;
 mod ni_psys_collider;
 mod ni_psys_collider_manager;
 mod ni_psys_color_modifier;
+mod ni_psys_cylinder_emitter;
 mod ni_psys_data;
 mod ni_psys_emitter;
 mod ni_psys_emitter_ctlr;
 mod ni_psys_gravity_modifier;
 mod ni_psys_grow_fade_modifier;
+mod ni_psys_mesh_emitter;
 mod ni_psys_modifier;
 mod ni_psys_modifier_ctlr;
 mod ni_psys_planar_collider;
 mod ni_psys_position_modifier;
+mod ni_psys_reset_on_loop_ctlr;
 mod ni_psys_rotation_modifier;
 mod ni_psys_spawn_modifier;
+mod ni_psys_sphere_emitter;
 mod ni_psys_update_ctlr;
 mod ni_psys_volume_emitter;
 
@@ -26,16 +30,20 @@ pub use ni_psys_box_emitter::*;
 pub use ni_psys_collider::*;
 pub use ni_psys_collider_manager::*;
 pub use ni_psys_color_modifier::*;
+pub use ni_psys_cylinder_emitter::*;
 pub use ni_psys_data::*;
 pub use ni_psys_emitter::*;
 pub use ni_psys_emitter_ctlr::*;
 pub use ni_psys_gravity_modifier::*;
 pub use ni_psys_grow_fade_modifier::*;
+pub use ni_psys_mesh_emitter::*;
 pub use ni_psys_modifier::*;
 pub use ni_psys_modifier_ctlr::*;
 pub use ni_psys_planar_collider::*;
 pub use ni_psys_position_modifier::*;
+pub use ni_psys_reset_on_loop_ctlr::*;
 pub use ni_psys_rotation_modifier::*;
 pub use ni_psys_spawn_modifier::*;
+pub use ni_psys_sphere_emitter::*;
 pub use ni_psys_update_ctlr::*;
 pub use ni_psys_volume_emitter::*;
