@@ -8,14 +8,17 @@ pub mod blocks;
 pub mod common;
 pub mod error;
 pub mod header;
+#[cfg(feature = "obj")]
+pub mod obj;
+
 mod parse_utils;
 
 #[derive(Debug, PartialEq, BinRead)]
 pub struct Nif {
     pub header: header::Header,
     #[br(args(
-        (&header).block_types.iter().map(|b| b.value.clone()).collect(),
-        (&header).block_type_index.clone(),
+        header.block_types.iter().map(|b| b.value.clone()).collect(),
+        header.block_type_index.clone(),
     ))]
     #[br(parse_with = parse_utils::parse_blocks)]
     pub blocks: Vec<blocks::Block>,
